==> aws_cdk.aws_kinesisfirehose_alpha-2.40.0a0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesisfirehose_alpha_IDeliveryStream(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryption(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.destinations))
            _aws_cdk_aws_kinesisfirehose_alpha_IDestination(p.destinations);
        if (!visitedObjects.has(p.encryption))
            _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryption(p.encryption);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamAttributes(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStream(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DestinationConfig(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DestinationBindOptions(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_IDestination(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_LambdaFunctionProcessor(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorProps(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorIdentifier(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorConfig(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.processorIdentifier))
            _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorIdentifier(p.processorIdentifier);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorBindOptions(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_IDataProcessor(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_kinesisfirehose_alpha_IDeliveryStream, _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryption, _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamProps, _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamAttributes, _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStream, _aws_cdk_aws_kinesisfirehose_alpha_DestinationConfig, _aws_cdk_aws_kinesisfirehose_alpha_DestinationBindOptions, _aws_cdk_aws_kinesisfirehose_alpha_IDestination, _aws_cdk_aws_kinesisfirehose_alpha_LambdaFunctionProcessor, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorProps, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorIdentifier, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorConfig, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorBindOptions, _aws_cdk_aws_kinesisfirehose_alpha_IDataProcessor };

==> aws_cdk.aws_kinesisfirehose_alpha-2.162.1a0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesisfirehose_alpha_IDeliveryStream(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryptionType(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.destination))
            _aws_cdk_aws_kinesisfirehose_alpha_IDestination(p.destination);
        if (!visitedObjects.has(p.encryption))
            _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryption(p.encryption);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamAttributes(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStream(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DestinationConfig(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DestinationBindOptions(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_IDestination(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryption(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_LambdaFunctionProcessor(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorProps(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorIdentifier(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorConfig(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.processorIdentifier))
            _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorIdentifier(p.processorIdentifier);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorBindOptions(p) {
}
function _aws_cdk_aws_kinesisfirehose_alpha_IDataProcessor(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_kinesisfirehose_alpha_IDeliveryStream, _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryptionType, _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamProps, _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStreamAttributes, _aws_cdk_aws_kinesisfirehose_alpha_DeliveryStream, _aws_cdk_aws_kinesisfirehose_alpha_DestinationConfig, _aws_cdk_aws_kinesisfirehose_alpha_DestinationBindOptions, _aws_cdk_aws_kinesisfirehose_alpha_IDestination, _aws_cdk_aws_kinesisfirehose_alpha_StreamEncryption, _aws_cdk_aws_kinesisfirehose_alpha_LambdaFunctionProcessor, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorProps, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorIdentifier, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorConfig, _aws_cdk_aws_kinesisfirehose_alpha_DataProcessorBindOptions, _aws_cdk_aws_kinesisfirehose_alpha_IDataProcessor };
